@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Acme::CPANAuthors::Utils qw( cpan_authors cpan_packages );
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub new {
   my ($class, @categories) = @_;
@@ -128,7 +128,9 @@ sub look_for {
   }
 
   my @found;
-  foreach my $category ( _list_categories() ) {
+  my @categories = ref $self ? @{ $self->{categories} } : ();
+  @categories = _list_categories() unless @categories;
+  foreach my $category ( @categories ) {
     my %authors = _get_authors_of($category);
     while ( my ($id, $name) = each %authors ) {
       if ($id =~ /$id_or_name/ or $name =~ /$id_or_name/) {
@@ -164,6 +166,8 @@ sub _get_authors_of {
       carp "$category CPAN Authors are not registered yet: $@";
       return;
     }
+    # some may actually lack 'authors' interface
+    return unless $package->can('authors');
   }
   $package->authors;
 }
